#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
#
# - this script contains examples of how to set the variables and execute
#   XCLASS outside CASA
# - play around with user parameters defined in lines 72 - 137
#
# Usage:
# - in the terminal
#   > python my_fit_OUTcasa__xml.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
# get path of current directory
LocalPath = os.getcwd() + "/"


###############################################################################
# TO MODIFY BY THE USER

# define path and name of default molfit file
DefaultMolfitFile = LocalPath + "my_LineID__default.molfit"

# define path and name of obs. xml file
experimentalData = LocalPath + "my_observation__LineID.xml"

# define list of molecules with are analyzed
SelectedMolecules = ["HCCCN;v=0;", "CH3OH;v=0;", "C2H5OH;v=0;", \
                     "CH3CN;v=0;", "SO;v=0;", "SO2;v=0;"]

# define noise level
Noise = 0.5

# define upper limit of overestimation
MaxOverestimationHeight = 500.0

# define tolerance
Tolerance = 65.0

# define max. number of iterations
NumberIteration = 10

# define path and name of algorithm xml files
AlgorithmXMLFileSMF = ""
AlgorithmXMLFileOverAll = ""

# define lower limit for column density of core components
MinColumnDensityEmis = 0.0

# define lower limit for column density of foreground components
MinColumnDensityAbs = 0.0

# define source name
SourceName = ""

# define list of so-called strong molecules
StrongMoleculeList = []

## define vLSR
vLSR = 0.0

## define vLSR
TelescopeSize = 10.0

## define vLSR
Inter_Flag = False

## define vLSR
tBack = 0.0

## define vLSR
tSlope = 0.0

## define vLSR
N_H = 0.0

## define vLSR
beta_dust = 0.0

## define vLSR
kappa_1300 = 0.0

## define path and name of cluster file
clusterdef = ""
###############################################################################


# call myXCLASSFit function
IdentifiedLines, JobDir = LineIdentification(Noise, MaxOverestimationHeight, \
                                             SourceName, DefaultMolfitFile, \
                                             Tolerance, SelectedMolecules, \
                                             StrongMoleculeList, \
                                             MinColumnDensityEmis, \
                                             MinColumnDensityAbs, \
                                             NumberIteration, \
                                             AlgorithmXMLFileSMF, \
                                             AlgorithmXMLFileOverAll, \
                                             experimentalData, vLSR, \
                                             TelescopeSize, Inter_Flag, tBack, \
                                             tSlope, N_H, beta_dust, \
                                             kappa_1300, clusterdef)



