#!/usr/bin/env python
#
# Python script executable within CASA
# XCLASS Fit and plot spectra
#
# Description:
#
# - this script contains examples of how to set the variables and execute
#   XCLASS wihtin CASA
# - play around with user parameters defined in lines 29 - 80
#
# Usage:
# - direct usage (within CASA)
#   CASA> execfile('my_fit_INcasa.py')
# - to be used remotely (from the terminal)
#   > screen
#   > casa --nologger --nogui -c my_fit_INcasa__no-xml.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# Fitting spectra with myXCLASSFit task


###############################################################################
# TO MODIFY BY THE USER

# define path and name of molfit file
MolfitsFileName = "my_molecules.molfit"

# define path and name of obs. data file
experimentalData = "data/observed_spectrum.dat"

# define max. number of iterations for fitting process
NumberIteration = 10

# define size of telescope (m) for single dish data and (") for
# interferometric data
TelescopeSize = 0.38

# define if interferometric data (True) or single dish data (False) is fitted
Inter_Flag = True

# use phenomenological description of continuum only
t_back_flag = True

# define background temperature (K)
tBack = 0.0

# define temperature slope
tslope = 0.0

# define if a global dust parameter defintion is used
nH_flag = True

# define hydrogen column density (cm^(-2))
N_H = 1.e24

# define spectral index
beta_Dust = 0.0

# define kappa
kappa_1300 = 0.0

# define if iso ratio file is used
iso_flag = True

# define path and name of iso ratio file
IsoTableFileName = "my_isonames.txt"

# define rest frequency (MHz)
RestFreq = 0.0

# define v_LSR (km/s)
vLSR = 0.0

# define path and name of algorithm xml file
AlgorithmXMLFile = ""
###############################################################################


# call myXCLASSFit function
newmolfit, modeldata, JobDir = myXCLASSFit()


# rename plot file produced by XCLASS
cmdString = "cp -rp " + JobDir + "final_plot.LM.out.png my_fit_example.png"
os.system(cmdString)
