#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
#
# - this script contains examples of how to set the variables and execute
#   XCLASS outside CASA
# - play around with user parameters defined in lines 77 - 128
#
# Usage:
# - in the terminal
#   > python my_fit_OUTcasa__no-xml.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
# get path of current directory
LocalPath = os.getcwd() + "/"


#------------------------------------------------------------------------------
# Fitting spectra with myXCLASSFit task


###############################################################################
# TO MODIFY BY THE USER

# define path and name of molfit file
MolfitsFileName = LocalPath + "my_molecules.molfit"

# define path and name of obs. data file
experimentalData = LocalPath + "data/observed_spectrum.dat"

# define max. number of iterations for fitting process
NumberIteration = 10

# define size of telescope (m) for single dish data and (") for
# interferometric data
TelescopeSize = 0.38

# define if interferometric data (True) or single dish data (False) is fitted
Inter_Flag = True

# only phenomenological description of continuum only
t_back_flag = True

# define background temperature (K)
tBack = 0.0

# define temperature slope
tslope = 0.0

# define if a global dust parameter defintion is used
nH_flag = True

# define hydrogen column density (cm^(-2))
N_H = 1.e24

# define spectral index
beta_Dust = 0.0

# define spectral index
kappa_1300 = 0.0

# define if iso ratio file is used
iso_flag = True

# define path and name of iso ratio file
IsoTableFileName = LocalPath + "my_isonames.txt"

# define rest frequency (MHz)
RestFreq = 0.0

# define v_LSR (km/s)
vLSR = 0.0

# define path and name of algorithm xml file
AlgorithmXMLFile = ""
###############################################################################


# call myXCLASSFit function
newmolfit, modeldata, JobDir = task_myXCLASSFit.myXCLASSFit(NumberIteration, \
                                            AlgorithmXMLFile, MolfitsFileName, \
                                            experimentalData, TelescopeSize, \
                                            Inter_Flag, t_back_flag, tBack, \
                                            tslope, nH_flag, N_H, beta_Dust, \
                                            kappa_1300, iso_flag, \
                                            IsoTableFileName, RestFreq, vLSR)


#------------------------------------------------------------------------------
# rename plot file produced by XCLASS
cmdString = "cp -rp " + JobDir + "final_plot.LM.out.png my_fit_example.png"
os.system(cmdString)

