#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
# - this script contains examples of how to set the variables and execute
#   XCLASS outside CASA
# - play around with user parameters defined in lines 71 - 91
#
# Usage:
# - in the terminal
#   > python my_list_OUTcasa.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
# example to list entries from the database


###############################################################################
# TO MODIFY BY THE USER

# define lower limit for transition frequencies (MHz)
my_minFreq = 210000.0

# define upper limit for transition frequencies (MHz)
my_maxFreq = 250000.0

# define lower limit for E_low (K)
my_minElow = 0.0

# define upper limit for E_low (K)
my_maxElow = 300.0

# restrict output to molecules defined in this list (if list is empty, print
# informations to all molecules which have at least one transititons frequency
# within the given limits)
my_molecules = ["CO;v=0;", "C-13-O;v=0;"]

# define path and name of output file (if no path is defined print output
# to screen)
OutputDevice = ''
###############################################################################


# call ListDatabase function
FreqMin = my_minFreq
FreqMax = my_maxFreq
ElowMin = my_minElow
ElowMax = my_maxElow
SelectMolecule = my_molecules
Contents = task_ListDatabase.ListDatabase(FreqMin, FreqMax, ElowMin, ElowMax, \
                                          SelectMolecule, OutputDevice)


