#!/usr/bin/env python
#
# Python script executable within CASA
# XCLASS Fit a datacube
#
# Description:
#
# - this script contains examples of how to set the variables
#   and execute XCLASS wihtin CASA
# - play around with user parameters defined in lines 29 - 93
#
# Usage:
# - direct usage (within CASA)
#   CASA> execfile('my_mapfit_INcasa.py')
# - to be used remotely (from the terminal)
#   > screen
#   > casa --nologger --nogui -c my_mapfit_INcasa__no-xml.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# Fitting spectra with myXCLASSMapFit task


###############################################################################
# TO MODIFY BY THE USER

# define max. number of iterations for fitting process
NumberIteration = 10

# define path and name of molfit file
MolfitsFileName = "my_map-molecules.molfit"

# define path and name of obs. data file
experimentalData = "data/CH3CN_datacube.fits"

# define path and name of region file
regionFileName = "my_map-region.reg"

# define if results of previous row is used
UsePreviousResults = False

# define lower limit for intensity (pixel with max. intensity below given
# limit are ignored)
Threshold = 0.0

# define size of telescope (m) for single dish data and (") for
# interferometric data
TelescopeSize = 84.1675

# define if interferometric data (True) or single dish data (False) is fitted
Inter_Flag = False

# use phenomenological description of continuum only
t_back_flag = False

# define background temperature (K)
tBack = 0.0

# define temperature slope
tslope = 0.0

# define if a global dust parameter defintion is used
nH_flag = False

# define hydrogen column density (cm^(-2))
N_H = 0.0

# define spectral index
beta_dust = 0.0

# define kappa
kappa_1300 = 0.0

# define if iso ratio file is used
iso_flag = True

# define path and name of iso ratio file
IsoTableFileName = "my_isonames.txt"

# define rest frequency (MHz)
RestFreq = 0.0

# define v_LSR (km/s)
vLSR = 0.0

# define path and name of so-called cluster file
clusterdef = ""

# define path and name of algorithm xml file
AlgorithmXMLFile = ""
###############################################################################


# call myXCLASSMapFit function
JobDir = myXCLASSMapFit()

