#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
# - this script contains examples of how to set the variables
#   and execute XCLASS outside CASA
# - play around with user parameters defined in lines 76 - 136
#
# Usage:
# - in the terminal
#   > python my_mapfit_OUTcasa__no-xml.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
## get path of current directory
LocalPath = os.getcwd() + "/"


#------------------------------------------------------------------------------
# Fitting spectra with myXCLASSMapFit task


###############################################################################
# TO MODIFY BY THE USER

# define max. number of iterations for fitting process
NumberIteration = 10

# define path and name of molfit file
MolfitsFileName = LocalPath + "my_map-molecules.molfit"

# define path and name of obs. data file
experimentalData = LocalPath + "data/CH3CN_datacube.fits"

# define path and name of region file
regionFileName = LocalPath + "my_map-region.reg"

# define if results of previous row is used
UsePreviousResults = False

# define lower limit for intensity (pixel with max. intensity below given
# limit are ignored)
Threshold = 0.0

# define lower limit of frequency range
FreqMin = 220468.0

# define upper limit of frequency range
FreqMax = 220769.0

# define size of telescope (m) for single dish data and (") for
# interferometric data
TelescopeSize = 84.1675

# define if interferometric data (True) or single dish data (False) is fitted
Inter_Flag = False

# use phenomenological description of continuum only
t_back_flag = True

# define background temperature (K)
tBack = 0.0

# define temperature slope
tslope = 0.0

# define if a global dust parameter defintion is used
nH_flag = True

# define hydrogen column density (cm^(-2))
N_H = 1.e24

# define spectral index
beta_dust = 0.0

# define kappa
kappa_1300 = 0.0

# define if iso ratio file is used
iso_flag = True

# define path and name of iso ratio file
IsoTableFileName = LocalPath + "my_isonames.txt"

# define rest frequency (MHz)
RestFreq = 0.0

# define v_LSR (km/s)
vLSR = 0.0

# define path and name of so-called cluster file
clusterdef = ""

# define path and name of algorithm xml file
AlgorithmXMLFile = ""
###############################################################################


# call myXCLASSMapFit function
JobDir = task_myXCLASSMapFit.myXCLASSMapFit(NumberIteration, AlgorithmXMLFile, \
                                            MolfitsFileName, experimentalData, \
                                            regionFileName, UsePreviousResults,\
                                            Threshold, FreqMin, FreqMax, \
                                            TelescopeSize, Inter_Flag, \
                                            t_back_flag, tBack, tslope, \
                                            nH_flag, N_H, beta_dust, \
                                            kappa_1300, iso_flag, \
                                            IsoTableFileName, RestFreq, vLSR, \
                                            clusterdef)

