#!/usr/bin/env python
#
# Python script executable within CASA
# XCLASS Plot spectra
#
# Description:
#
# - this script contains the basic commands to
#   plot observed and synthetic spectra
# - play around with user parameters defined in lines 56 - 94
#
# Usage:
# - direct usage (within CASA)
#   CASA> execfile('my_plot_INcasa.py')
# - to be used remotely (from the terminal)
#   > screen
#   > casa --nologger --nogui -c my_plot_INcasa.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# Creating the synthetic spectra with myXCLASS task
FreqMin = 219764.24
FreqMax = 221471.74
FreqStep = 0.1
TelescopeSize = 0.38
Inter_Flag = True
t_back_flag = True
tBack = 0.0
tslope = 0.0
nH_flag = True
N_H = 1.e24
beta_dust = 0.0
kappa_1300 = 0.0
MolfitsFileName = "my_molecules.molfit"
iso_flag = True
IsoTableFileName = "my_isonames.txt"
RestFreq = 0.0
vLSR = 0.0
modeldata, log, TransEnergies, IntOptical, JobDir = myXCLASS()

#------------------------------------------------------------------------------
# Loading an ascii file with observed data
FileName = 'data/observed_spectrum.dat'
NumHeaderLines = 0
expdata = LoadASCIIFile()

#------------------------------------------------------------------------------
# Plotting spectra


###############################################################################
# TO MODIFY BY THE USER

# define array containting obs. data
expdata = expdata

# define array containting synthetic spectrum
modeldata = modeldata

# define array containing transition eneriges
TransEnergies = TransEnergies

# define rest frequency (MHz)
RestFreq = 0.0

# define v_LSR (km/s)
vLSR = 0.0

# define lower limit for E_low (K)
MinTransEnergy = 0.0

# define lower limit for frequency axis (MHz)
xLowerLimit = 219764.24

# define upper limit for frequency axis (MHz)
xUpperLimit = 221471.74

# define lower limit for intensity axis (K)
yLowerLimit = -0.6

# define upper limit for intensity axis (K)
yUpperLimit = 6.0

# define title of plot
PlotTitle = "Example for myXCLASSPlot function"

# add legend to plot?
LegendFlag = True

# define path and name of output file
SaveFigureFile = "my_plot_example.png"
###############################################################################


# call myXCLASSPlot function
myXCLASSPlot()
