#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
# - this script contains examples of how to set the variables
#   and execute XCLASS outside CASA
# - play around with user parameters defined in lines 112 - 149
#
# Usage:
# - in the terminal
#   > python my_plot_OUTcasa.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
## get path of current directory
LocalPath = os.getcwd() + "/"


#------------------------------------------------------------------------------
# Creating the synthetic spectra with myXCLASS task
FreqMin = 219764.24
FreqMax = 221471.74
FreqStep = 0.1
TelescopeSize = 0.38
Inter_Flag = True
t_back_flag = True
tBack = 0.0
tslope = 0.0
nH_flag = True
N_H = 1.e24
beta_dust = 0.0
kappa_1300 = 0.0
MolfitsFileName = LocalPath + "my_molecules.molfit"
iso_flag = True
IsoTableFileName = LocalPath + "my_isonames.txt"
RestFreq = 0.0
vLSR = 0.0
modeldata, log, TransEnergies, IntOptical, JobDir = task_myXCLASS.myXCLASS( \
                                                FreqMin, FreqMax, FreqStep, \
                                                TelescopeSize, Inter_Flag, \
                                                t_back_flag, tBack, tslope, \
                                                nH_flag, N_H, beta_dust, \
                                                kappa_1300, MolfitsFileName, \
                                                iso_flag, IsoTableFileName, \
                                                RestFreq, vLSR)

#------------------------------------------------------------------------------
# Loading an ascii file with observed data
FileName = 'data/observed_spectrum.dat'
NumHeaderLines = 0
expdata = task_LoadASCIIFile.LoadASCIIFile(FileName, NumHeaderLines, \
                                           RestFreq, vLSR)

#------------------------------------------------------------------------------
# Plotting spectra


###############################################################################
# TO MODIFY BY THE USER

# define array containting obs. data
expdata = expdata

# define array containting synthetic spectrum
modeldata = modeldata

# define array containing transition eneriges
TransEnergies = TransEnergies

# define rest frequency (MHz)
RestFreq = 0.0

# define v_LSR (km/s)
vLSR = 0.0

# define lower limit for E_low (K)
MinTransEnergy = 0.0

# define lower limit for frequency axis (MHz)
xLowerLimit = 219764.24

# define upper limit for frequency axis (MHz)
xUpperLimit = 221471.74

# define lower limit for intensity axis (K)
yLowerLimit = -0.6

# define upper limit for intensity axis (K)
yUpperLimit = 6.0

# define title of plot
PlotTitle = "Example for myXCLASSPlot function"

# add legend to plot?
LegendFlag = True

# define path and name of output file
SaveFigureFile = LocalPath + "my_plot_example.png"
###############################################################################


# call myXCLASSPlot function
task_myXCLASSPlot.myXCLASSPlot(expdata, modeldata, TransEnergies, RestFreq, \
                               vLSR, MinTransEnergy, xLowerLimit, xUpperLimit, \
                               yLowerLimit, yUpperLimit, PlotTitle, \
                               LegendFlag, SaveFigureFile)


