#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
# - this script contains examples of how to set the variables
#   and execute XCLASS outside CASA
# - play around with user parameters defined in lines 76 - 87
#
# Usage:
# - in the terminal
#   > python my_query_OUTcasa.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
## get path of current directory
LocalPath = os.getcwd() + "/"


#------------------------------------------------------------------------------
# send SQL query to database


###############################################################################
# TO MODIFY BY THE USER (comment/uncomment lines defining QueryString variable


# EXAMPLE 1: get names of all molecules included in the database
QueryString = "select PF_Name from Partitionfunctions"


# EXAMPLE 2: get names of all molecules with transition frequencies between
#            two given frequencies included in the database
#    FreqMin = 10000.0
#    FreqMax = 12000.0
#    QueryString = "select T_Name from transitions where T_Frequency >= "
#    QueryString += str(FreqMin) + " and T_Frequency <= " + str(FreqMax)
###############################################################################


# call DatabaseQuery function
Contents = task_DatabaseQuery.DatabaseQuery(QueryString)



