#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Python script of how to use XCLASS outside CASA
#
# Description:
# - this script contains examples of how to set the variables
#   and execute XCLASS outside CASA
# - play around with user parameters defined in lines 111 - 117
#
# Usage:
# - in the terminal
#   > python my_transitions_OUTcasa.py
#
# Version 07/2015, Sanchez-Monge
#******************************************************************************


#------------------------------------------------------------------------------
# import python packages
import sys
import os
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
# extend sys.path variable


# get path of XCLASS directory
XCLASSRootDir = str(os.environ.get('XCLASSRootDir', ''))
XCLASSRootDir = XCLASSRootDir.strip()
if (XCLASSRootDir != ""):
    NewModulesPaths = XCLASSRootDir
else:
    # enter path manually, if XCLASSRootDir variable is not defined in bashrc
    XCLASSRootDir= "/home/sanchez/software/XCLASS/v_1.2.3/XCLASS-Interface"


# extend sys.path variable
NewModulesPath = XCLASSRootDir + "/build_tasks/"
already_included_flag = False
for entries in sys.path:
	if (entries == NewModulesPath):
		already_included_flag = True
		break
	if (not already_included_flag):
		sys.path.append(NewModulesPath)


# import XCLASS packages
import task_UpdateDatabase
import task_DatabaseQuery
import task_ListDatabase
import task_LoadASCIIFile
import task_GetTransitions
import task_MAGIX
import task_myXCLASS
import task_myXCLASSPlot
import task_myXCLASSFit
import task_myXCLASSMapFit
import task_myXCLASSMapRedoFit


#------------------------------------------------------------------------------
## get path of current directory
LocalPath = os.getcwd() + "/"


#------------------------------------------------------------------------------
# Creating the synthetic spectra with myXCLASS task
FreqMin = 219764.24
FreqMax = 221471.74
FreqStep = 0.1
TelescopeSize = 0.38
Inter_Flag = True
t_back_flag = True
tBack = 0.0
tslope = 0.0
nH_flag = True
N_H = 1.e24
beta_dust = 0.0
kappa_1300 = 0.0
MolfitsFileName = LocalPath + "my_molecules.molfit"
iso_flag = True
IsoTableFileName = LocalPath + "my_isonames.txt"
RestFreq = 0.0
vLSR = 0.0
modeldata, log, TransEnergies, IntOptical, JobDir = task_myXCLASS.myXCLASS( \
                                                FreqMin, FreqMax, FreqStep, \
                                                TelescopeSize, Inter_Flag, \
                                                t_back_flag, tBack, tslope, \
                                                nH_flag, N_H, beta_dust, \
                                                kappa_1300, MolfitsFileName, \
                                                iso_flag, IsoTableFileName, \
                                                RestFreq, vLSR)

#------------------------------------------------------------------------------
# Loading an ascii file with observed data
FileName = LocalPath + "data/observed_spectrum.dat"
NumHeaderLines = 0
expdata = task_LoadASCIIFile.LoadASCIIFile(FileName, NumHeaderLines, \
                                           RestFreq, vLSR)

#------------------------------------------------------------------------------
# example of an interactive selection of a frequency range


###############################################################################
# TO MODIFY BY THE USER

# define array containting obs. data
expdata = expdata

# define array containting synthetic spectrum
modeldata = modeldata

# define lower limit for transition frequencies (MHz)
FreqMin = 0.0

# define upper limit for transition frequencies (MHz)
FreqMax = 1.e8

# define lower limit for E_low (K)
ElowMin = 0.0

# define upper limit for E_low (K)
ElowMax = 100.0

# restrict output to molecules defined in this list (if list is empty, print
# informations to all molecules which have at least one transititons frequency
# within the given limits)
SelectMolecule = []

# define half width of frequency range (MHz) whose central frequency is
# selected within the GUI
FrequencyWidth = 20.0
###############################################################################


# call GetTransitions function
task_GetTransitions.GetTransitions(expdata, FreqMin, FreqMax, SelectMolecule, \
                                   FrequencyWidth, ElowMin, ElowMax, modeldata)


